==> weather-icons-lite-1.3.0.tgz: package/css_mappings.md <==
# Weather CSS Mapping
| Wunderground                                                 | Darksky                        | Openweathermap | Icon Name |           icon           |
| :-------------------------- | :----------------- | :------------- | :-------- | :----------------------: |
| wi-wu-clear<br />wi-wu-sunny | wi-darksky-clear-day           | wi-owm-01d     | f00d      |   ![](images/f00d.jpg)   |
| wi-wu-nt_clear<br />wi-wu-nt_mostlysunny<br />wi-wu-nt_sunny | wi-darksky-clear-night         | wi-owm-01n     | f02e      |   ![](images/f02e.jpg)   |
| wi-wu-chancerain                                             | wi-darksky-rain                | wi-owm-10d     | f019      |   ![](images/f019.jpg) |
| wi-wu-chancesnow<br />wi-wu-snow                             | wi-darksky-snow                | wi-owm-13d     | f01b      |   ![](images/f01b.jpg)   |
| wi-wu-chancesleet<br />wi-wu-sleet                           | wi-darksky-sleet               |                | f0b5      |   ![](images/f0b5.jpg)   |
| wi-wu-fog                                                    | wi-darksky-fog                 | wi-owm-50d     | f014      |   ![](images/f014.jpg)   |
|                                                              | wi-darksky-wind                |                | f050      |   ![](images/f050.jpg)   |
|                                                              | wi-darksky-cloudy              | wi-owm-04d     | f013      |   ![](images/f013.jpg)   |
| wi-wu-cloudy<br />wi-wu-mostlycloud<br />wi-wu-partlycloudy<br />wi-wu-partlysunny | wi-darksky-partly-cloudy-day   | wi-owm-03d     | f002      |   ![](images/f002.jpg)   |
| wi-wu-nt_partlysunny                                         | wi-darksky-partly-cloudy-night | wi-owm-04n     | f086      |   ![](images/f086.jpg)   |
|                                                              | wi-darksky-hail                |                | f015      |   ![](images/f015.jpg)   |
| wi-wu-chancetstorm<br />wi-wu-tstorms                        | wi-darksky-thunderstorm        | wi-owm-11d     | f01e      |   ![](images/f01e.jpg)   |
|                                                              | wi-darksky-tornado             |                | f056      |   ![](images/f056.jpg)   |
| wi-wu-mostlysunny |                                | wi-owm-02d     | f00c      |   ![](images/f00c.jpg)   |
|                                                              |                                | wi-owm-09d     | f017      |   ![](images/f017.jpg)   |
| wi-wu-nt_mostlycloudy<br />wi-wu-nt_partlycloudy             |                                | wi-owm-02n     | f081      |   ![](images/f081.jpg)   |
| wi-wu-nt_hazy                                                |                                | wi-owm-03n     | f07e      |   ![](images/f07e.jpg)   |
|                                                              |                                | wi-owm-09n     | f026      |   ![](images/f026.jpg)   |
| wi-wu-nt_chancerain<br />wi-wu-nt_rain                       |                                | wi-owm-10n     | f028      |   ![](images/f028.jpg)   |
|                                                              |                                | wi-owm-11n     | f02c      |   ![](images/f02c.jpg)   |
| wi-wu-nt_chancesnow<br />wi-wu-nt_snow                       |                                | wi-owm-13n     | f02a      |   ![](images/f02a.jpg)   |
| wi-wu-nt_fog                                                 |                                | wi-owm-50n     | f04a      |   ![](images/f04a.jpg)   |
| wi-wu-chanceflurries<br />wi-wu-flurries                     |                                |                | f064      |   ![](images/f064.jpg)   |
| wi-wu-hazy                                                   |                                |                | f0b6      |   ![](images/f0b6.jpg)   |
| wi-wu-rain                                                   |                                |                | f01a      |   ![](images/f01a.jpg)   |
| wi-wu-nt_chanceflurries<br />wi-wu-nt_flurries               |                                |                | f067      |   ![](images/f067.jpg)   |
| wi-wu-nt_chancesleet<br />wi-wu-nt_sleet                     |                                |                | f0b4      |   ![](images/f0b4.jpg)   |
| wi-wu-nt_chancetstorms<br />wi-wu-nt_tstorms                 |                                |                | f02d      |   ![](images/f02d.jpg)   |
| wi-wu-nt_cloudy                                              |                                |                | f031      |   ![](images/f031.jpg)   |

# Moon phase CSS Mapping
| Generic                                                 | Icon Name |           icon           |
| :-------------------------- | :-------- | :----------------------: |
| wi-moon-new                    | f0dd      |   ![](images/moon1.JPG)   |
| wi-moon-wax-cres               | f0de      |   ![](images/moon2.JPG)   |
| wi-moon-first-quart            | f0df      |   ![](images/moon3.JPG)   |
| wi-moon-wax-gibb               | f0e0      |   ![](images/moon4.JPG)   |
| wi-moon-full                   | f0e1      |   ![](images/moon5.JPG)   |
| wi-moon-wan-gibb               | f0da      |   ![](images/moon6.JPG)   |
| wi-moon-third-quart            | f0db      |   ![](images/moon7.JPG)   |
| wi-moon-wan-cres               | f0dc      |   ![](images/moon8.JPG)   |

==> weather-icons-lite-1.5.0.tgz: package/css_mappings.md <==
# Weather CSS Mapping
| Wunderground                                                 | Darksky                        | Openweathermap | Icon Name |           icon           |
| :-------------------------- | :----------------- | :------------- | :-------- | :----------------------: |
| wi-wu-clear<br />wi-wu-sunny | wi-darksky-clear-day           | wi-owm-01d     | f00d      |   ![](images/f00d.jpg)   |
| wi-wu-nt_clear<br />wi-wu-nt_mostlysunny<br />wi-wu-nt_sunny | wi-darksky-clear-night         | wi-owm-01n     | f02e      |   ![](images/f02e.jpg)   |
| wi-wu-chancerain                                             | wi-darksky-rain                | wi-owm-10d     | f019      |   ![](images/f019.jpg) |
| wi-wu-chancesnow<br />wi-wu-snow                             | wi-darksky-snow                | wi-owm-13d     | f01b      |   ![](images/f01b.jpg)   |
| wi-wu-chancesleet<br />wi-wu-sleet                           | wi-darksky-sleet               |                | f0b5      |   ![](images/f0b5.jpg)   |
| wi-wu-fog                                                    | wi-darksky-fog                 | wi-owm-50d     | f014      |   ![](images/f014.jpg)   |
|                                                              | wi-darksky-wind                |                | f050      |   ![](images/f050.jpg)   |
|                                                              | wi-darksky-cloudy              | wi-owm-04d     | f013      |   ![](images/f013.jpg)   |
| wi-wu-cloudy<br />wi-wu-mostlycloud<br />wi-wu-partlycloudy<br />wi-wu-partlysunny | wi-darksky-partly-cloudy-day   | wi-owm-03d     | f002      |   ![](images/f002.jpg)   |
| wi-wu-nt_partlysunny                                         | wi-darksky-partly-cloudy-night | wi-owm-04n     | f086      |   ![](images/f086.jpg)   |
|                                                              | wi-darksky-hail                |                | f015      |   ![](images/f015.jpg)   |
| wi-wu-chancetstorm<br />wi-wu-tstorms                        | wi-darksky-thunderstorm        | wi-owm-11d     | f01e      |   ![](images/f01e.jpg)   |
|                                                              | wi-darksky-tornado             |                | f056      |   ![](images/f056.jpg)   |
| wi-wu-mostlysunny |                                | wi-owm-02d     | f00c      |   ![](images/f00c.jpg)   |
|                                                              |                                | wi-owm-09d     | f017      |   ![](images/f017.jpg)   |
| wi-wu-nt_mostlycloudy<br />wi-wu-nt_partlycloudy             |                                | wi-owm-02n     | f081      |   ![](images/f081.jpg)   |
| wi-wu-nt_hazy                                                |                                | wi-owm-03n     | f07e      |   ![](images/f07e.jpg)   |
|                                                              |                                | wi-owm-09n     | f026      |   ![](images/f026.jpg)   |
| wi-wu-nt_chancerain<br />wi-wu-nt_rain                       |                                | wi-owm-10n     | f028      |   ![](images/f028.jpg)   |
|                                                              |                                | wi-owm-11n     | f02c      |   ![](images/f02c.jpg)   |
| wi-wu-nt_chancesnow<br />wi-wu-nt_snow                       |                                | wi-owm-13n     | f02a      |   ![](images/f02a.jpg)   |
| wi-wu-nt_fog                                                 |                                | wi-owm-50n     | f04a      |   ![](images/f04a.jpg)   |
| wi-wu-chanceflurries<br />wi-wu-flurries                     |                                |                | f064      |   ![](images/f064.jpg)   |
| wi-wu-hazy                                                   |                                |                | f0b6      |   ![](images/f0b6.jpg)   |
| wi-wu-rain                                                   |                                |                | f01a      |   ![](images/f01a.jpg)   |
| wi-wu-nt_chanceflurries<br />wi-wu-nt_flurries               |                                |                | f067      |   ![](images/f067.jpg)   |
| wi-wu-nt_chancesleet<br />wi-wu-nt_sleet                     |                                |                | f0b4      |   ![](images/f0b4.jpg)   |
| wi-wu-nt_chancetstorms<br />wi-wu-nt_tstorms                 |                                |                | f02d      |   ![](images/f02d.jpg)   |
| wi-wu-nt_cloudy                                              |                                |                | f031      |   ![](images/f031.jpg)   |

# Moon phase CSS Mapping
| CSS Code                                                 | Icon Name |           icon           |
| :-------------------------- | :-------- | :----------------------: |
| wi-moon-new                    | f0e1      |   ![](images/moon5.JPG)   |
| wi-moon-wax-cres               | f0da      |   ![](images/moon6.JPG)   |
| wi-moon-first-quart            | f0db      |   ![](images/moon7.JPG)   |
| wi-moon-wax-gibb               | f0dc      |   ![](images/moon8.JPG)   |
| wi-moon-full                   | f0dd      |   ![](images/moon1.JPG)   |
| wi-moon-wan-gibb               | f0de      |   ![](images/moon2.JPG)   |
| wi-moon-third-quart            | f0df      |   ![](images/moon3.JPG)   |
| wi-moon-wan-cres               | f0e0      |   ![](images/moon4.JPG)   |

**NOTE** - Because the Moon icons are representative of a 'physical moon', it is necessary to have an additional version for the dark theme, to avoid the icon colour becoming inverted. The dark theme version is obtained by adding `-dark` to the CSS code. For example to get the full moon (light theme version) the code would be `wi-moon-full`, whilst the same icon for a dark theme, the CSS code would be `wi-moon-full-dark`.
